@@ -90,7 +90,7 @@ class BiCoN(object):
         scores = []
         avs = []
         count_big = 0
-        max_total_score = 0
+        max_total_score = -100
         n1, n2 = (0,0)
         max_round_score = -100
         av_score = 0
